Summary: Secure Shell - provides secure encrypted network communications
Name: ssh2
Version: 2.0.13
Release: 1i
Source0: ftp://ftp.cs.hut.fi/pub/ssh/ssh-%{PACKAGE_VERSION}.tar.gz
Source1: ftp://ftp.cs.hut.fi/pub/ssh/ssh-%{PACKAGE_VERSION}.tar.gz.sig
Source2: sshd2.init.rh50
Patch0: ssh2_config.patch
Patch1: ssh-2.0.13-build.patch
Vendor: SSH Communications Security Ltd., Finland
URL: http://www.ssh.fi
#Patch: ssh-linux.patch
Copyright: Free for non-commercial use (see LICENSING)
Group: Applications/Internet
Packager: Miguel Armas <kuko@dis.ulpgc.es>
Buildroot: /tmp/ssh2-buildroot

%description
Secure Shell (ssh) provides secure encrypted communication between hosts
over an insecure network. It also has the ability to redirect X11 connections
and arbitrary TCP/IP ports over the secure encrypted channel.

SSHv2 is an almost complete rewrite of SSH. It provides a number of
enhancements over the previous version (SSHv1). One of them is the utility
sftp that permits encrypted file transfers.

SSHv2 needs the SSHv1 programs for backwards compatibility, so if you need
to connect to SSHv1 servers or clients you need to install SSHv1 BEFORE
these packages...

This is a base package. To use ssh you will need to install at least
ssh-clients or ssh-server.

%package server
Group: Applications/Internet
Summary: Secure Shell servers (sshd, sftp-server)
Requires: ssh2 >= 2.0.0 chkconfig >= 0.9

%description server
This package contains the secure shell servers and its documentation.
These servers allows ssh clients to connect to your host. 

It (still?) doesn't support PAM...

%package clients
Summary: Clients to connect to SSH Servers
Group: Applications/Internet
Requires: ssh2 >= 2.0.0

%description clients
This package contains the clients needed to make encrypted connections to
ssh servers.

%package extras
Summary: Extra commands for the Secure Shell utils
Group: Applications/Internet
Requires: ssh2 >= 2.0.0

%description extras
This package contains the make_ssh_known_hosts
the ssh-askpass command and its documentation. They were moved
to the separate package to allow clean install of ssh even
on X11-less and perl-less machines (make_ssh_known_hosts is a perl script
and ssh-askpass uses X11 libraries.

%prep
%setup -n ssh-${RPM_PACKAGE_VERSION}

%patch0 -p1
%patch1 -p1

%build
./configure --prefix=/usr
make

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr $RPM_BUILD_ROOT/etc/rc.d/init.d
make prefix=$RPM_BUILD_ROOT/usr etcdir=$RPM_BUILD_ROOT/etc install
install -m755 $RPM_SOURCE_DIR/sshd2.init.rh50 $RPM_BUILD_ROOT/etc/rc.d/init.d/sshd2
strip $RPM_BUILD_ROOT/usr/sbin/* $RPM_BUILD_ROOT/usr/bin/* 

%post
# Fix symlinks in binary utils
for i in /usr/bin/ssh-keygen /usr/bin/scp; do
  ln -sf `basename $i`2 $i
done

# Fix symlinks in manpages
for i in /usr/man/man1/ssh-keygen.1 /usr/man/man1/scp.1; do
  CHAPTER=${i#*.}; PROG=${i%.$CHAPTER}
  ln -sf `basename $PROG`2.$CHAPTER ${PROG}.$CHAPTER
done

# Generate hostkey
if [ ! -f /etc/ssh2/hostkey -o ! -s /etc/ssh2/hostkey ]; then
   umask 022; \
   echo "Generating 1024 bit host key. This may take a while, go and have a coffee ;)"; \
   /usr/bin/ssh-keygen2 -P -b 1024 -t dsa -c "1024-bit dsa hostkey" \
                     -o /etc/ssh2/hostkey
fi

%preun
# If last instance..
if [ "$1" = 0 ]; then
   # Symlink to SSHv1 utils if they exist, or delete symlink if they don't
   for i in /usr/bin/ssh-keygen /usr/bin/scp; do
     if [ -f "$i"1 ]; then
        ln -sf `basename $i`1 $i
     else
        rm -f $i
     fi
   done
   # Symlink to SSHv1 manpages if they exist, or delete symlink if they don't
   for i in /usr/man/man1/ssh-keygen.1 /usr/man/man1/scp.1; do
     CHAPTER=${i#*.}; PROG=${i%.$CHAPTER}
     if [ -f "$PROG"1.$CHAPTER ]; then
        ln -sf `basename $PROG`1.$CHAPTER ${PROG}.$CHAPTER
     else
        rm -f $i
     fi   
   done
fi

%post server
# Fix symlinks in binary utils
for i in /usr/sbin/sshd /usr/bin/sftp-server; do
  ln -sf `basename $i`2 $i
done

# Fix symlinks in manpages
for i in /usr/man/man8/sshd.8; do
  CHAPTER=${i#*.}; PROG=${i%.$CHAPTER}
  ln -sf `basename $PROG`2.$CHAPTER ${PROG}.$CHAPTER
done

# If sshd1 is configured to run, delete it...
if /sbin/chkconfig sshd; then
   echo "executing: chkconfig --del sshd"
   /etc/rc.d/init.d/sshd stop >&2
   /sbin/chkconfig --del sshd 
fi

# Install init scripts and start service
/sbin/chkconfig --add sshd2
/etc/rc.d/init.d/sshd2 restart >&2

%preun server
# If last instance..
if [ "$1" = 0 ]; then
   # Uninstall init scripts and stop service
   /etc/rc.d/init.d/sshd2 stop >&2
   /sbin/chkconfig --del sshd2
   
   # If we have SSHv1, chkconfig it..
   if [ -f /etc/rc.d/init.d/sshd ]; then
      echo "executing: chkconfig --add sshd"
      /sbin/chkconfig --add sshd
   fi
   
   # Symlink to SSHv1 utils if they exist, or delete symlink if they don't
   for i in /usr/sbin/sshd /usr/bin/sftp-server; do
     if [ -f "$i"1 ]; then
        ln -sf `basename $i`1 $i
     else
        rm -f $i
     fi
   done
   # Symlink to SSHv1 manpages if they exist, or delete symlink if they don't
   for i in /usr/man/man8/sshd.8; do
     CHAPTER=${i#*.}; PROG=${i%.$CHAPTER}
     if [ -f "$PROG"1.$CHAPTER ]; then
        ln -sf `basename $PROG`1.$CHAPTER ${PROG}.$CHAPTER
     else
        rm -f $i
     fi   
   done
fi

%post clients
# Fix symlinks in binary utils
for i in /usr/bin/ssh /usr/bin/ssh-agent /usr/bin/ssh-add /usr/bin/sftp; do
  ln -sf `basename $i`2 $i
done

# Fix symlinks in manpages
for i in /usr/man/man1/ssh.1 /usr/man/man1/ssh-agent.1 \
         /usr/man/man1/ssh-add.1 /usr/man/man1/sftp.1; do
  CHAPTER=${i#*.}; PROG=${i%.$CHAPTER}
  ln -sf `basename $PROG`2.$CHAPTER ${PROG}.$CHAPTER
done

%preun clients
# If last instance..
if [ "$1" = 0 ]; then
   # Symlink to SSHv1 utils if they exist, or delete symlink if they don't
   for i in /usr/bin/ssh /usr/bin/ssh-agent /usr/bin/ssh-add /usr/bin/sftp; do
     if [ -f "$i"1 ]; then
        ln -sf `basename $i`1 $i
     else
        rm -f $i
     fi
   done
   # Symlink to SSHv1 manpages if they exist, or delete symlink if they don't
   for i in /usr/man/man1/ssh.1 /usr/man/man1/ssh-agent.1 \
         /usr/man/man1/ssh-add.1 /usr/man/man1/sftp.1; do
     CHAPTER=${i#*.}; PROG=${i%.$CHAPTER}
     if [ -f "$PROG"1.$CHAPTER ]; then
        ln -sf `basename $PROG`1.$CHAPTER ${PROG}.$CHAPTER
     else
        rm -f $i
     fi   
   done
fi

%post extras
# Fix symlinks in binary utils
for i in /usr/bin/ssh-askpass; do
  ln -sf `basename $i`2 $i
done

%preun extras
# If last instance..
if [ "$1" = 0 ]; then
   # Symlink to SSHv1 utils if they exist, or delete symlink if they don't
   for i in /usr/bin/ssh-askpass; do
     if [ -f "$i"1 ]; then
        ln -sf `basename $i`1 $i
     else
        rm -f $i
     fi
   done
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(0644,root,root,0755)
%doc CHANGES LICENSING README SSH2.QUICKSTART
%attr(0755,root,root) /usr/bin/ssh-keygen2
%attr(0755,root,root) /usr/bin/scp2
%attr(0644,root,root) %doc /usr/man/man1/ssh-keygen2.1
%attr(0644,root,root) %doc /usr/man/man1/scp2.1
#%attr(-,root,root) %ghost /usr/bin/ssh-keygen
#%attr(-,root,root) %ghost /usr/bin/scp
#%attr(-,root,root) %ghost /usr/man/man1/ssh-keygen.1
#%attr(-,root,root) %ghost /usr/man/man1/scp.1
%attr(0755,root,root) %dir /etc/ssh2

%files server
%defattr(0644,root,root,0755)
%attr(0644,root,root) %config /etc/ssh2/sshd2_config
%attr(0755,root,root) /usr/sbin/sshd2
%attr(0755,root,root) /usr/bin/sftp-server2
%attr(0644,root,root) %doc /usr/man/man8/sshd2.8
#%attr(-,root,root) %ghost /usr/sbin/sshd
#%attr(-,root,root) %ghost /usr/bin/sftp-server
#%attr(-,root,root) %ghost /usr/man/man8/sshd.8
# Still don't have a pam patch :(
# %attr(0644,root,root) /etc/pam.d/ssh
%attr(0755,root,root) /etc/rc.d/init.d/sshd2

%files clients
%defattr(0644,root,root,0755)
%attr(0644,root,root) %config /etc/ssh2/ssh2_config
%attr(0755,root,root) /usr/bin/ssh2
%attr(4755,root,root) /usr/bin/ssh-signer2
%attr(0755,root,root) /usr/bin/ssh-agent2
%attr(0755,root,root) /usr/bin/ssh-add2
%attr(0755,root,root) /usr/bin/sftp2
%attr(0644,root,root) %doc /usr/man/man1/ssh2.1
%attr(0644,root,root) %doc /usr/man/man1/ssh-agent2.1
%attr(0644,root,root) %doc /usr/man/man1/ssh-add2.1
%attr(0644,root,root) %doc /usr/man/man1/sftp2.1
#%attr(-,root,root) %ghost /usr/bin/ssh
#%attr(-,root,root) %ghost /usr/bin/ssh-agent
#%attr(-,root,root) %ghost /usr/bin/ssh-add
#%attr(-,root,root) %ghost /usr/bin/sftp
#%attr(-,root,root) %ghost /usr/man/man1/ssh.1
#%attr(-,root,root) %ghost /usr/man/man1/ssh-agent.1
#%attr(-,root,root) %ghost /usr/man/man1/ssh-add.1
#%attr(-,root,root) %ghost /usr/man/man1/sftp.1

%files extras  
%defattr(0644,root,root,0755)
%attr(0755,root,root) /usr/bin/ssh-askpass2
#%attr(-,root,root) %ghost /usr/bin/ssh-askpass

%changelog

* Wed May 12 1999 Peter Soos <sp@osb.hu>
- Update to ssh-2.0.13.
- Corrected the file and directory attributes to rebuild the package
  under RedHat Linux 6.0

* Thu Apr 22 1999 Peter Soos <sp@osb.hu>
- Update to ssh-2.0.12.

* Fri Dec 11 1998 Miguel Armas <kuko@dis.ulpgc.es>
- Update to ssh-2.0.11

* Mon Dec 07 1998 Miguel Armas <kuko@dis.ulpgc.es>
- Keep out symlinks to avoid conflicts with SSHv1. Make symlinks on install
- Fix restart server...
- On last uninstall, make symlinks to SSHv1 utils if they exist...
- On last uninstall, configure sshd1 to start on boot...
- Add %doc to manpages
- Fix ownership in %doc files

* Sat Dec 05 1998 Miguel Armas <kuko@dis.ulpgc.es>
- Initial revision
